@@ -215,7 +215,10 @@ class TestSQLite3toMySQL:
         ]
         if with_rowid:
             arguments.append("--with-rowid")
-        result = cli_runner.invoke(sqlite3mysql, arguments,)
+        result = cli_runner.invoke(
+            sqlite3mysql,
+            arguments,
+        )
         assert result.exit_code == 0
 
     def test_keyboard_interrupt(
@@ -300,3 +303,81 @@ class TestSQLite3toMySQL:
                 "tqdm",
             }
         )
+
+    @pytest.mark.parametrize(
+        "mysql_integer_type, mysql_string_type, chunk, with_rowid",
+        [
+            # 0000
+            (None, None, None, False),
+            # 0001
+            (None, None, None, True),
+            # 1110
+            ("BIGINT(19)", "TEXT", 10, False),
+            # 1111
+            ("BIGINT(19)", "TEXT", 10, True),
+            # 1100
+            ("BIGINT(19)", "TEXT", None, False),
+            # 1101
+            ("BIGINT(19)", "TEXT", None, True),
+            # 0110
+            (None, "TEXT", 10, False),
+            # 0111
+            (None, "TEXT", 10, True),
+            # 0100
+            (None, "TEXT", None, False),
+            # 0101
+            (None, "TEXT", None, True),
+            # 1000
+            ("BIGINT(19)", None, None, False),
+            # 1001
+            ("BIGINT(19)", None, None, True),
+            # 0010
+            (None, None, 10, False),
+            # 0011
+            (None, None, 10, True),
+            # 1010
+            ("BIGINT(19)", None, 10, False),
+            # 1011
+            ("BIGINT(19)", None, 10, True),
+        ],
+    )
+    def test_quiet(
+        self,
+        cli_runner,
+        sqlite_database,
+        mysql_credentials,
+        mysql_integer_type,
+        mysql_string_type,
+        mysql_database,
+        chunk,
+        with_rowid,
+    ):
+        arguments = [
+            "-f",
+            sqlite_database,
+            "-d",
+            mysql_credentials.database,
+            "-u",
+            mysql_credentials.user,
+            "-p",
+            mysql_credentials.password,
+            "-h",
+            mysql_credentials.host,
+            "-P",
+            mysql_credentials.port,
+            "--mysql-integer-type",
+            mysql_integer_type,
+            "--mysql-string-type",
+            mysql_string_type,
+            "-c",
+            chunk,
+            "-q",
+        ]
+        if with_rowid:
+            arguments.append("--with-rowid")
+        result = cli_runner.invoke(
+            sqlite3mysql,
+            arguments,
+        )
+        assert result.exit_code == 0
+        assert result.output == ""
